@@ -1,4 +1,6 @@
 import requests
 import bs4 as bs
 import re
+from tqdm import tqdm
+import pandas as pd
 from camp_parser.camp_parser import camphub_parser
\ No newline at end of file
